window.Gleam.initSearch([{"doc":"gladvent","title":"gladvent","content":"# Gladvent\n\n[![Hex Package](https://img.shields.io/hexpm/v/gladvent?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/gladvent)\n[![Hex.pm](https://img.shields.io/hexpm/dt/gladvent?color=ffaff3)](https://hex.pm/packages/gladvent)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/gladvent/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/gladvent/main)](https://github.com/tanklesxl/gladvent/actions)\n\nAn Advent Of Code runner for Gleam\n\nThis library is intended to be imported to your gleam project and used as a command runner for your advent of code project in gleam.\n\nTo add this library to your project run: `gleam add gladvent` and add `import gladvent` to your main gleam file.\n\n## Using the library\n\nThis library provides 2 options to run your advent of code solvers,\nonce you&#39;ve added gladvent as a dependency via `gleam add gladvent`:\n\n1. The easiest way: call it via `gleam run -m gladvent [ARGS]`, not requiring a custom `main()` function.\n1. The easy way: simply add `gladvent.main()` to the end of your project&#39;s `main` function.\n\n## Multi-year support\n\nGladvent now comes with out-of-the-box multi-year support via the `--year` flag when running it.\n\nFor convenience it defaults to the current year. Therefore, passing `--year=YEAR` to either the `run`, `run all` or `new` commands will use the year specified or the current year if the flag was not provided.\n\n## Available commands\n\nThis project provides your application with 2 commands, `new` and `run`:\n\n- `new`: create `src/days/*.gleam` and `input/*.txt` files that correspond to the specified days\n\n  - format: `gleam run -m gladvent new a b c ...`\n  - used like `gleam run -m gladvent new 1 2` with days 1 and 2 creates `input/day_1.txt` and `input/day_2.txt` as well as `src/days/day_1.gleam` and `src/days/day_2.gleam`\n\n- `run`: run the specified days\n\n  - format: `gleam run -m gladvent run a b c ...`\n  - flags:\n    - `--timeout`: `gleam run -m gladvent run --timeout={timeout in ms} a b c ...`\n      - usage example: `gleam run run --timeout=1000 1 2` with timeout 1000 milliseconds and days 1 and 2, runs and prints the output of running the `run` function of `day_1.gleam` and `day_2.gleam`\n    - `--allow-crash`: runs days without the use of `rescue` functionality, rendering output text more verbose but also allowing for stacktraces to be printed\n      - usage example: `gleam run -m gladvent run 1 2 3 --allow-crash`\n\n- `run all`: run all registered days\n  - format: `gleam run -m gladvent run all`\n  - flags:\n    - `--timeout`: `gleam run -m gladvent run all --timeout={timeout in ms}`\n      - usage example: `gleam run run --timeout=1000 1 2` with timeout 1000 milliseconds and days 1 and 2, runs and prints the output of running the `run` function of `day_1.gleam` and `day_2.gleam`\n    - `--allow-crash`: runs days without the use of `rescue` functionality, rendering output text more verbose but also allowing for stacktraces to be printed\n      - usage example: `gleam run -m gladvent run all --allow-crash`\n\n_Note:_\n\n- the `new` command creates source files in `src/aoc_&lt;YEAR&gt;/` and input files in the `input/&lt;YEAR&gt;` directory.\n- the `run` command expects input files to be in the `input/&lt;YEAR&gt;` directory, and code to be in `src/aoc_&lt;YEAR&gt;/`\n- any triggered `assert` will be captured and printed, for example: `error: assert - Assertion pattern match failed in module days/day_1 in function pt_1 at line 2 with value 2`\n- any message in a `todo` will be captured and printed, for example: `error: todo - test in module days/day_1 in function pt_2 at line 7`\n\n## Seeing help messages\n\n- To see available subcommands: `gleam run -m gladvent -- --help`\n- To see help for the `run` command: `gleam run -m gladvent run --help`\n- To see help for the `run` command: `gleam run -m gladvent run all --help`\n- To see help for the `new` command: `gleam run -m gladvent new --help`\n\n## General Workflow\n\nWhere X is the day you&#39;d like to add (when using `gladvent.main()`):\n\n_Note:_ this method requires all day solutions be in `src/days/` with filenames `day_X.gleam`, each solution module containing `fn pt_1(String) -&gt; Int` and a `fn pt_2(String) -&gt; Int`\n\n1. run `gleam run -m gladvent run new X`\n2. add your input to `input/&lt;YEAR&gt;/day_X.txt`\n3. add your code to `src/aoc_&lt;YEAR&gt;/day_X.gleam`\n4. run `gleam run -m gladvent run X`\n\n## Reusable parse funtions\n\nAs of `v0.7.0` gladvent supports modules with functions that provide a `pub fn parse(String)-&gt;a` where the type `a` matches with the type of the argument for the runner functions `pt_1` and `pt_2`. If this function is present, gladvent will pick it up and run it only once, providing the output to both runner functions.\n\nAn example of which looks like this:\n\n```gleam\npub fn parse(input: String) -&gt; Int {\n    let assert Ok(i) = int.parse(input)\n    i\n}\n\npub fn pt_1(input: Int) -&gt; Int {\n    i + 1\n}\n\npub fn pt_2(input: Int) -&gt; Int {\n    i + 2\n}\n```\n\n_Note_: `gladvent` now leverages gleam&#39;s `export package-interface` functionality to type-check your `parse` and `pt_{1|2}` functions to make sure that they are compatible with each other.\n\n## FAQ\n\n### Why did you make this?\n\nIt seemed fun, I like small command line utilities and I wanted a way to get advent of code done in gleam without having the additional overhead of lots of copy-pasting and connecting things to get it to run\n\n### Why does this not download the input from the advent of code website?\n\nA few reasons:\n\n1. I wanted to keep this utility as simple as possible to start with\n2. I like the advent of code website and I felt like it was a shame to circumvent visiting it, especially since you should access it to read the daily challenge. On top of that, I would like to avoid spamming the `advent of code` api if possible.\n\n### Why run as a command line utility and not just use unit tests?\n\nI thought a lot about that and I prefer the overall interactivity of a CLI better, as well as allowing for endless runs or runs with configurable timeouts. Having it run as part of `eunit` doesnt provide as much flexibility as I would like.\n","url":"index.html"},{"doc":"gladvent","title":"main","content":"pub fn main() -&gt; Nil\n Find all runners in the project src/days/ directory and\n run either the &#39;run&#39; or &#39;new&#39; command as specified\n\nSynonyms:\ngladvent.main\ngladvent main","url":"gladvent.html#main"},{"doc":"gladvent","title":"gladvent","content":"","url":"gladvent.html"}]);